#
# spec file for package go1.16
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


# strip will cause Go's .a archives to become invalid because strip appears to
# reassemble the archive incorrectly. This is a known issue upstream
# (https://github.com/golang/go/issues/17890), but we have to deal with it in
# the meantime.
%undefine _build_create_debug
%define __arch_install_post export NO_BRP_STRIP_DEBUG=true NO_BRP_AR=true

%if 0%{?suse_version} == 1315
%define gcc_go_version 6
%define go_bootstrap_version go1.4
%else
%ifarch riscv64
%define go_bootstrap_version go1.14
%else
%define go_bootstrap_version go1.9
%endif
%if 0%{?sle_version} == 150000
# SLE15 or Leap 15.x
%define gcc_go_version 7
%else
%define gcc_go_version 9
%endif
%endif

# By default use go and not gccgo
%bcond_with    gccgo

# The fallback boostrap method via %%{go_bootstrap_version} would work for Leap
# but we don't have %%{go_bootstrap_version} in there. Same for SLE15+
#if ( 0%{?suse_version} < 1550 && 0%{?is_opensuse} ) || ( 0%{?suse_version} >= 1500 && ! 0%{?is_opensuse} )
#bcond_without gccgo
#endif

# The fallback bootstrap method via go1.4 doesn't work
# for aarch64 nor ppc64le because go 1.4 did not support that architecture.
%if 0%{?suse_version} == 1315
%ifarch aarch64 ppc64le ppc64 s390x
%bcond_without gccgo
%endif
%endif

# gccgo on ppc64le with default PIE enabled fails with:
# error while loading shared libraries:
# R_PPC64_ADDR16_HA re10143fb0c for symbol `' out of range
# track https://github.com/golang/go/issues/28531
# linuxppc-dev discussion:
# "PIE binaries are no longer mapped below 4 GiB on ppc64le"
# https://lists.ozlabs.org/pipermail/linuxppc-dev/2018-November/180862.html
%ifarch ppc64le
#!BuildIgnore: gcc-PIE
%endif

# Build go-race only on platforms where it's supported (both amd64 and aarch64
# requires SLE15-or-later because of C++14, and ppc64le doesn't build at all
# on openSUSE yet).
%if 0%{?suse_version} >= 1500 || 0%{?sle_version} >= 150000
%define tsan_arch x86_64 aarch64
%else
# Cannot use {nil} here (ifarch doesn't like it) so just make up a fake
# architecture that no build will ever match.
%define tsan_arch openSUSE_FAKE_ARCH
%endif

# Go has precompiled versions of LLVM's compiler-rt inside their source code.
# We cannot ship pre-compiled binaries so we have to recompile said source,
# however they vendor specific commits from upstream. This value comes from
# src/runtime/race/README (and we verify that it matches in check).
#
# In order to update the TSAN version, modify _service. See boo#1052528 for
# more details.
%define tsan_commit 89f7ccea6f6488c443655880229c54db1f180153

%define go_api 1.16

# shared library support
%if "%{rpm_vercmp %{go_api} 1.5}" > "0"
%if %{with gccgo}
%define with_shared 1
%else
%ifarch %ix86 %arm x86_64 aarch64
%define with_shared 1
%else
%define with_shared 0
%endif
%endif
%else
%define with_shared 0
%endif
%ifarch ppc64
%define with_shared 0
%endif
# setup go_arch (BSD-like scheme)
%ifarch %ix86
%define go_arch 386
%endif
%ifarch x86_64
%define go_arch amd64
%endif
%ifarch aarch64
%define go_arch arm64
%endif
%ifarch %arm
%define go_arch arm
%endif
%ifarch ppc64
%define go_arch ppc64
%endif
%ifarch ppc64le
%define go_arch ppc64le
%endif
%ifarch s390x
%define go_arch s390x
%endif
%ifarch riscv64
%define go_arch riscv64
%endif

Name:           go1.16
Version:        1.16
Release:        lp152.2.1
Summary:        A compiled, garbage-collected, concurrent programming language
License:        BSD-3-Clause
Group:          Development/Languages/Other
URL:            http://golang.org
Source:         http://golang.org/dl/go%{version}.src.tar.gz
Source1:        go-rpmlintrc
Source4:        README.SUSE
Source6:        go.gdbinit
# We have to compile TSAN ourselves. boo#1052528
Source100:      llvm-%{tsan_commit}.tar.xz
# PATCH-FIX-UPSTREAM marguerite@opensuse.org - find /usr/bin/go-5 when bootstrapping with gcc5-go
Patch8:         gcc6-go.patch
Patch9:         gcc7-go.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# boostrap
%if %{with gccgo}
%ifnarch s390 s390x
BuildRequires:  binutils-gold
%endif
BuildRequires:  gcc%{gcc_go_version}-go
%else
# no gcc-go
BuildRequires:  %{go_bootstrap_version}
%endif
BuildRequires:  fdupes
Recommends:     %{name}-doc = %{version}
%ifarch %{tsan_arch}
# Needed to compile compiler-rt/TSAN.
BuildRequires:  gcc-c++
%endif
#BNC#818502 debug edit tool of rpm fails on i586 builds
BuildRequires:  rpm >= 4.11.1
# Needed on arm aarch64 to avoid
# collect2: fatal error: cannot find 'ld'-
%ifarch %arm aarch64
BuildRequires:  binutils-gold
%endif
Requires(post):	update-alternatives
Requires(postun):	update-alternatives
# Needed on arm aarch64 to avoid
# collect2: fatal error: cannot find 'ld'-
%ifarch %arm aarch64
%if 0%{?is_opensuse}
Requires:       binutils-gold
%else
Recommends:     binutils-gold
%endif
%endif
Requires:       gcc
Provides:       go = %{version}
Provides:       go-devel = go%{version}
Provides:       go-devel-static = go%{version}
Provides:       golang(API) = %{go_api}
Obsoletes:      go-devel < go%{version}
# go-vim/emacs were separate projects starting from 1.4
Obsoletes:      go-emacs <= 1.3.3
Obsoletes:      go-vim <= 1.3.3
ExclusiveArch:  %ix86 x86_64 %arm aarch64 ppc64 ppc64le s390x riscv64

%description
Go is an expressive, concurrent, garbage collected systems programming language
that is type safe and memory safe. It has pointers but no pointer arithmetic.
Go has fast builds, clean syntax, garbage collection, methods for any type, and
run-time reflection. It feels like a dynamic language but has the speed and
safety of a static language.

%package doc
Summary:        Go documentation
Group:          Documentation/Other
Requires:       %{name} = %{version}
Provides:       go-doc = %{version}

%description doc
Go examples and documentation.

%ifarch %{tsan_arch}
# boo#1052528
%package race
Summary:        Go runtime race detector
Group:          Development/Languages/Other
URL:            https://compiler-rt.llvm.org/
Requires:       %{name} = %{version}
Supplements:    %{name} = %{version}
ExclusiveArch:  %{tsan_arch}

%description race
Go runtime race detector libraries. Install this package if you wish to use the
-race option, in order to detect race conditions present in your Go programs.
%endif

%prep
%ifarch %{tsan_arch}
# compiler-rt (from LLVM)
%setup -q -T -b 100 -n llvm-%{tsan_commit}
%endif
# go
%setup -q -n go
%if %{with gccgo}
%if 0%{?gcc_go_version} == 6
%patch8 -p1
%endif
%if 0%{?gcc_go_version} == 7
%patch9 -p1
%endif
%endif

cp %{SOURCE4} .

%build
# Remove the pre-included .sysos, to avoid shipping things we didn't compile
# (which is against the openSUSE guidelines for packaging).
find . -type f -name '*.syso' -print -delete

# First, compile LLVM's TSAN, and replace the built-in with it. We can only do
# this for amd64.
%ifarch %{tsan_arch}
TSAN_DIR="../llvm-%{tsan_commit}/compiler-rt/lib/tsan/go"
pushd "$TSAN_DIR"
./buildgo.sh
popd
cp -v "$TSAN_DIR/race_linux_%{go_arch}.syso" src/runtime/race/
%endif

# Now, compile Go.
%if %{with gccgo}
export GOROOT_BOOTSTRAP=%{_prefix}
%else
export GOROOT_BOOTSTRAP=%{_libdir}/%{go_bootstrap_version}
%endif
# Ensure ARM arch is set properly - boo#1169832
%ifarch armv6l armv6hl
export GOARCH=arm
export GOARM=6
%endif
%ifarch armv7l armv7hl
export GOARCH=arm
export GOARM=7
%endif
export GOROOT="`pwd`"
export GOROOT_FINAL=%{_libdir}/go/%{go_api}
export GOBIN="$GOROOT/bin"
mkdir -p "$GOBIN"
cd src
HOST_EXTRA_CFLAGS="%{optflags} -Wno-error" ./make.bash -v

cd ../
%ifarch %{tsan_arch}
# Install TSAN-friendly version of the std libraries.
bin/go install -race std
%endif

%if %{with_shared}
bin/go install -buildmode=shared -linkshared std
%endif

%check
%ifarch %{tsan_arch}
# Make sure that we have the right TSAN checked out.
grep "^race_linux_%{go_arch}.syso built with LLVM %{tsan_commit}" src/runtime/race/README
%endif

%install
export GOROOT="%{buildroot}%{_libdir}/go/%{go_api}"

# locations for third party libraries, see README-openSUSE for info about locations.
install -d  %{buildroot}%{_datadir}/go/%{go_api}/contrib
install -d  $GOROOT/contrib/pkg/linux_%{go_arch}
ln -s %{_libdir}/go/%{go_api}/contrib/pkg/ %{buildroot}%{_datadir}/go/%{go_api}/contrib/pkg
install -d  %{buildroot}%{_datadir}/go/%{go_api}/contrib/cmd
install -d  %{buildroot}%{_datadir}/go/%{go_api}/contrib/src
ln -s %{_datadir}/go/%{go_api}/contrib/src/ %{buildroot}%{_libdir}/go/%{go_api}/contrib/src
install -Dm644 README.SUSE $GOROOT/contrib/
ln -s %{_libdir}/go/%{go_api}/contrib/README.SUSE %{buildroot}%{_datadir}/go/%{go_api}/contrib/README.SUSE

# source files for go install, godoc, etc
install -d %{buildroot}%{_datadir}/go/%{go_api}
for ext in *.{go,c,h,s,S,py,syso}; do
  find src -name ${ext} -exec install -Dm644 \{\} %{buildroot}%{_datadir}/go/%{go_api}/\{\} \;
done
mkdir -p $GOROOT/src
for i in $(ls %{buildroot}/usr/share/go/%{go_api}/src);do
  ln -s /usr/share/go/%{go_api}/src/$i $GOROOT/src/$i
done
# add lib files that are needed (such as the timezone database).
install -d $GOROOT/lib
find lib -type f -exec install -D -m644 {} $GOROOT/{} \;

# copy document templates, packages, obj libs and command utilities
mkdir -p $GOROOT/bin
# remove bootstrap
rm -rf pkg/bootstrap
mv pkg $GOROOT
mv bin/* $GOROOT/bin
mkdir -p $GOROOT/misc/trace
mv misc/trace/* $GOROOT/misc/trace
# add wasm (Web Assembly) boo#1139210
mkdir -p $GOROOT/misc/wasm
mv misc/wasm/* $GOROOT/misc/wasm
rm -f %{buildroot}%{_bindir}/{hgpatch,quietgcc}

# gdbinit
install -Dm644 %{SOURCE6} $GOROOT/bin/gdbinit.d/go.gdb
%if "%{_lib}" == "lib64"
sed -i "s/lib/lib64/" $GOROOT/bin/gdbinit.d/go.gdb
sed -i "s/\$go_api/%{go_api}/" $GOROOT/bin/gdbinit.d/go.gdb
%endif

# update-alternatives
 mkdir -p %{buildroot}%{_sysconfdir}/alternatives
 mkdir -p %{buildroot}%{_bindir}
 mkdir -p %{buildroot}%{_sysconfdir}/profile.d
 mkdir -p %{buildroot}%{_sysconfdir}/gdbinit.d
 touch %{buildroot}%{_sysconfdir}/alternatives/{go,gofmt,go.gdb}
 ln -sf %{_sysconfdir}/alternatives/go %{buildroot}%{_bindir}/go
 ln -sf %{_sysconfdir}/alternatives/gofmt %{buildroot}%{_bindir}/gofmt
 ln -sf %{_sysconfdir}/alternatives/go.gdb %{buildroot}%{_sysconfdir}/gdbinit.d/go.gdb

# documentation and examples
# fix documetation permissions (rpmlint warning)
find doc/ misc/ -type f -exec chmod 0644 '{}' +
# remove unwanted arch-dependant binaries (rpmlint warning)
rm -rf misc/cgo/test/{_*,*.o,*.out,*.6,*.8}
# prepare go-doc
mkdir -p %{buildroot}%{_docdir}/go/%{go_api}
cp -r AUTHORS CONTRIBUTORS CONTRIBUTING.md LICENSE PATENTS README.md README.SUSE %{buildroot}%{_docdir}/go/%{go_api}
cp -r doc/* %{buildroot}%{_docdir}/go/%{go_api}

%fdupes -s %{buildroot}%{_prefix}

%post

update-alternatives \
  --install %{_bindir}/go go %{_libdir}/go/%{go_api}/bin/go $((20+$(echo %{go_api} | cut -d. -f2))) \
  --slave %{_bindir}/gofmt gofmt %{_libdir}/go/%{go_api}/bin/gofmt \
  --slave %{_sysconfdir}/gdbinit.d/go.gdb go.gdb %{_libdir}/go/%{go_api}/bin/gdbinit.d/go.gdb

%postun
if [ $1 -eq 0 ] ; then
	update-alternatives --remove go %{_libdir}/go/%{go_api}/bin/go
fi

%files
%{_bindir}/go
%{_bindir}/gofmt
%dir %{_libdir}/go
%{_libdir}/go/%{go_api}
%dir %{_datadir}/go
%{_datadir}/go/%{go_api}
%dir %{_sysconfdir}/gdbinit.d/
%config %{_sysconfdir}/gdbinit.d/go.gdb
%ghost %{_sysconfdir}/alternatives/go
%ghost %{_sysconfdir}/alternatives/gofmt
%ghost %{_sysconfdir}/alternatives/go.gdb
%dir %{_docdir}/go
%dir %{_docdir}/go/%{go_api}
%doc %{_docdir}/go/%{go_api}/AUTHORS
%doc %{_docdir}/go/%{go_api}/CONTRIBUTORS
%doc %{_docdir}/go/%{go_api}/CONTRIBUTING.md
%doc %{_docdir}/go/%{go_api}/PATENTS
%doc %{_docdir}/go/%{go_api}/README.md
%doc %{_docdir}/go/%{go_api}/README.SUSE
%if 0%{?suse_version} < 1500
%doc %{_docdir}/go/%{go_api}/LICENSE
%else
%license %{_docdir}/go/%{go_api}/LICENSE
%endif%

# We don't include TSAN in the main Go package.
%ifarch %{tsan_arch}
%exclude %{_datadir}/go/%{go_api}/src/runtime/race/race_linux_%{go_arch}.syso
%endif

%files doc
%defattr(-,root,root,-)
%doc %{_docdir}/go/%{go_api}/*.html

%ifarch %{tsan_arch}
%files race
%{_datadir}/go/%{go_api}/src/runtime/race/race_linux_%{go_arch}.syso
%endif

%changelog
* Thu Feb 18 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- gcc6-go.patch fix typo go-7 to go-6 for bootstrap on SLE-12 gcc6
* Tue Feb 16 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.16 (released 2021-02-16) Go 1.16 is a major release of Go.
  go1.16.x minor releases will be provided through February 2022.
  https://github.com/golang/go/wiki/Go-Release-Cycle
  Most changes are in the implementation of the toolchain, runtime,
  and libraries. As always, the release maintains the Go 1 promise
  of compatibility. We expect almost all Go programs to continue to
  compile and run as before.
  Refs boo#1182345 go1.16 release tracking
  * See release notes https://golang.org/doc/go1.16. Excerpts
    relevant to OBS environment and for SUSE/openSUSE follow:
  * Module-aware mode is enabled by default, regardless of whether
    a go.mod file is present in the current working directory or a
    parent directory. More precisely, the GO111MODULE environment
    variable now defaults to on. To switch to the previous
    behavior, set GO111MODULE to auto.
  * Build commands like go build and go test no longer modify
    go.mod and go.sum by default. Instead, they report an error if
    a module requirement or checksum needs to be added or updated
    (as if the -mod=readonly flag were used). Module requirements
    and sums may be adjusted with go mod tidy or go get.
  * go install now accepts arguments with version suffixes (for
    example, go install example.com/cmd@v1.0.0). This causes go
    install to build and install packages in module-aware mode,
    ignoring the go.mod file in the current directory or any parent
    directory, if there is one. This is useful for installing
    executables without affecting the dependencies of the main
    module.
  * go install, with or without a version suffix (as described
    above), is now the recommended way to build and install
    packages in module mode. go get should be used with the -d flag
    to adjust the current module's dependencies without building
    packages, and use of go get to build and install packages is
    deprecated. In a future release, the -d flag will always be
    enabled.
  * retract directives may now be used in a go.mod file to indicate
    that certain published versions of the module should not be
    used by other modules. A module author may retract a version
    after a severe problem is discovered or if the version was
    published unintentionally.
  * The go mod vendor and go mod tidy subcommands now accept the -e
    flag, which instructs them to proceed despite errors in
    resolving missing packages.
  * The go command now ignores requirements on module versions
    excluded by exclude directives in the main module. Previously,
    the go command used the next version higher than an excluded
    version, but that version could change over time, resulting in
    non-reproducible builds.
  * In module mode, the go command now disallows import paths that
    include non-ASCII characters or path elements with a leading
    dot character (.). Module paths with these characters were
    already disallowed (see Module paths and versions), so this
    change affects only paths within module subdirectories.
  * The go command now supports including static files and file
    trees as part of the final executable, using the new //go:embed
    directive. See the documentation for the new embed package for
    details.
  * When using go test, a test that calls os.Exit(0) during
    execution of a test function will now be considered to
    fail. This will help catch cases in which a test calls code
    that calls os.Exit(0) and thereby stops running all future
    tests. If a TestMain function calls os.Exit(0) that is still
    considered to be a passing test.
  * go test reports an error when the -c or -i flags are used
    together with unknown flags. Normally, unknown flags are passed
    to tests, but when -c or -i are used, tests are not run.
  * The go get -insecure flag is deprecated and will be removed in
    a future version. This flag permits fetching from repositories
    and resolving custom domains using insecure schemes such as
    HTTP, and also bypasses module sum validation using the
    checksum database. To permit the use of insecure schemes, use
    the GOINSECURE environment variable instead. To bypass module
    sum validation, use GOPRIVATE or GONOSUMDB. See go help
    environment for details.
  * go get example.com/mod@patch now requires that some version of
    example.com/mod already be required by the main
    module. (However, go get -u=patch continues to patch even
    newly-added dependencies.)
  * GOVCS is a new environment variable that limits which version
    control tools the go command may use to download source
    code. This mitigates security issues with tools that are
    typically used in trusted, authenticated environments. By
    default, git and hg may be used to download code from any
    repository. svn, bzr, and fossil may only be used to download
    code from repositories with module paths or package paths
    matching patterns in the GOPRIVATE environment variable. See go
    help vcs for details.
  * When the main module's go.mod file declares go 1.16 or higher,
    the all package pattern now matches only those packages that
    are transitively imported by a package or test found in the
    main module. (Packages imported by tests of packages imported
    by the main module are no longer included.) This is the same
    set of packages retained by go mod vendor since Go 1.11.
  * When the -toolexec build flag is specified to use a program
    when invoking toolchain programs like compile or asm, the
    environment variable TOOLEXEC_IMPORTPATH is now set to the
    import path of the package being built.
  * The -i flag accepted by go build, go install, and go test is
    now deprecated. The -i flag instructs the go command to install
    packages imported by packages named on the command line. Since
    the build cache was introduced in Go 1.10, the -i flag no
    longer has a significant effect on build times, and it causes
    errors when the install directory is not writable.
  * When the -export flag is specified, the BuildID field is now
    set to the build ID of the compiled package. This is equivalent
    to running go tool buildid on go list -exported -f {{.Export}},
    but without the extra step.
  * The -overlay flag specifies a JSON configuration file
    containing a set of file path replacements. The -overlay flag
    may be used with all build commands and go mod subcommands. It
    is primarily intended to be used by editor tooling such as
    gopls to understand the effects of unsaved changes to source
    files. The config file maps actual file paths to replacement
    file paths and the go command and its builds will run as if the
    actual file paths exist with the contents given by the
    replacement file paths, or don't exist if the replacement file
    paths are empty.
  * The cgo tool will no longer try to translate C struct bitfields
    into Go struct fields, even if their size can be represented in
    Go. The order in which C bitfields appear in memory is
    implementation dependent, so in some cases the cgo tool
    produced results that were silently incorrect.
  * The linux/riscv64 port now supports cgo and -buildmode=pie.
    This release also includes performance optimizations and code
    generation improvements for RISC-V.
  * The new runtime/metrics package introduces a stable interface
    for reading implementation-defined metrics from the Go
    runtime. It supersedes existing functions like
    runtime.ReadMemStats and debug.GCStats and is significantly
    more general and efficient. See the package documentation for
    more details.
  * Setting the GODEBUG environment variable to inittrace=1 now
    causes the runtime to emit a single line to standard error for
    each package init, summarizing its execution time and memory
    allocation. This trace can be used to find bottlenecks or
    regressions in Go startup performance. The GODEBUG
    documentation describes the format.
  * On Linux, the runtime now defaults to releasing memory to the
    operating system promptly (using MADV_DONTNEED), rather than
    lazily when the operating system is under memory pressure
    (using MADV_FREE). This means process-level memory statistics
    like RSS will more accurately reflect the amount of physical
    memory being used by Go processes. Systems that are currently
    using GODEBUG=madvdontneed=1 to improve memory monitoring
    behavior no longer need to set this environment variable.
  * Go 1.16 fixes a discrepancy between the race detector and the
    Go memory model. The race detector now more precisely follows
    the channel synchronization rules of the memory model. As a
    result, the detector may now report races it previously missed.
  * linker: This release includes additional improvements to the Go
    linker, reducing linker resource usage (both time and memory)
    and improving code robustness/maintainability. These changes
    form the second half of a two-release project to modernize the
    Go linker.
  * The linker changes in 1.16 extend the 1.15 improvements to all
    supported architecture/OS combinations (the 1.15 performance
    improvements were primarily focused on ELF-based OSes and amd64
    architectures). For a representative set of large Go programs,
    linking is 20-25%% faster than 1.15 and requires 5-15%% less
    memory on average for linux/amd64, with larger improvements for
    other architectures and OSes. Most binaries are also smaller as
    a result of more aggressive symbol pruning.
  * The new embed package provides access to files embedded in the
    program during compilation using the new //go:embed directive.
  * The new io/fs package defines the fs.FS interface, an
    abstraction for read-only trees of files. The standard library
    packages have been adapted to make use of the interface as
    appropriate.
  * For testing code that implements fs.FS, the new testing/fstest
    package provides a TestFS function that checks for and reports
    common mistakes. It also provides a simple in-memory file
    system implementation, MapFS, which can be useful for testing
    code that accepts fs.FS implementations.
  * syscall: On Linux, Setgid, Setuid, and related calls are now
    implemented. Previously, they returned an syscall.EOPNOTSUPP
    error. On Linux, the new functions AllThreadsSyscall and
    AllThreadsSyscall6 may be used to make a system call on all Go
    threads in the process. These functions may only be used by
    programs that do not use cgo; if a program uses cgo, they will
    always return syscall.ENOTSUP.
  * time/tzdata: The slim timezone data format is now used for the
    timezone database in $GOROOT/lib/time/zoneinfo.zip and the
    embedded copy in this package. This reduces the size of the
    timezone database by about 350 KB.
* Thu Jan 28 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.16rc1 (released 2021-01-28) is a release candidate of go1.16
  cut from the master branch at the revision tagged go1.16rc1.
* Thu Dec 17 2020 Jeff Kowalczyk <jkowalczyk@suse.com>
- go1.16beta1 (released 2020-12-08) is a beta version of go1.16 cut
  from the master branch at the revision tagged go1.16beta1.
